pub struct NetworkRequest<T: ConnectionTransport> {
pub base: BaseParameters,
/* private fields */
}Expand description
Represents a network request that can be intercepted
Fields
base: BaseParametersImplementations
Sourceimpl<T: ConnectionTransport> NetworkRequest<T>
impl<T: ConnectionTransport> NetworkRequest<T>
pub fn new( params: BeforeRequestSentParams, session: Arc<Mutex<BidiSession<T>>>, ) -> Self
pub fn from_auth_required( params: AuthRequiredParams, session: Arc<Mutex<BidiSession<T>>>, ) -> Self
Sourcepub fn request_id(&self) -> &Request
pub fn request_id(&self) -> &Request
Get the request ID
Sourcepub fn has_post_data(&self) -> bool
pub fn has_post_data(&self) -> bool
Check if the request has POST data (Chrome-specific)
Sourcepub fn post_data(&self) -> Option<&str>
pub fn post_data(&self) -> Option<&str>
Get the POST data as a raw string if available (Chrome-specific)
Sourcepub fn post_data_json(&self) -> Result<Map<String, Value>, PostDataError>
pub fn post_data_json(&self) -> Result<Map<String, Value>, PostDataError>
Parse the POST data as JSON (Chrome-specific) Returns an error if POST data is missing, not valid JSON, or not a JSON object
Sourcepub fn post_data_form(&self) -> Result<HashMap<String, String>, PostDataError>
pub fn post_data_form(&self) -> Result<HashMap<String, String>, PostDataError>
Parse the POST data as URL-encoded form data (Chrome-specific) Returns an error if POST data is missing
Sourcepub async fn is_handled(&self) -> bool
pub async fn is_handled(&self) -> bool
Check if this request has already been handled
Sourcepub async fn get_handled_state(&self) -> Option<NetworkRequestHandledState>
pub async fn get_handled_state(&self) -> Option<NetworkRequestHandledState>
Get the handled state if the request was already handled
Sourcepub async fn continue_(&self) -> Receiver<CommandResponseState>
pub async fn continue_(&self) -> Receiver<CommandResponseState>
Continue the request without modifications
Sourcepub async fn continue_with(
&self,
continue_request: ContinueRequestBuilder,
) -> Receiver<CommandResponseState>
pub async fn continue_with( &self, continue_request: ContinueRequestBuilder, ) -> Receiver<CommandResponseState>
Continue the request with modifications
Sourcepub async fn abort(&self) -> Receiver<CommandResponseState>
pub async fn abort(&self) -> Receiver<CommandResponseState>
Abort/fail the request
Sourcepub async fn respond(
&self,
provide_response_builder: ProvideResponseBuilder,
) -> Receiver<CommandResponseState>
pub async fn respond( &self, provide_response_builder: ProvideResponseBuilder, ) -> Receiver<CommandResponseState>
Provide a custom response
Sourcepub async fn continue_with_auth(
&self,
credentials: AuthCredentials,
) -> Result<(), SessionSendError>
pub async fn continue_with_auth( &self, credentials: AuthCredentials, ) -> Result<(), SessionSendError>
Continue with HTTP authentication
pub async fn continue_with_no_auth( &self, action: ContinueWithAuthNoCredentialsAction, ) -> Result<(), SessionSendError>